==> huaweicloudsdkaos-3.1.12-py2.py3-none-any.whl: huaweicloudsdkaos/v1/model/stack_event_response.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class StackEventResponse:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id_key': 'str',
        'resource_id_value': 'str',
        'resource_name': 'str',
        'resource_type': 'str',
        'time': 'str',
        'event_type': 'str',
        'event_message': 'str',
        'elapsed_seconds': 'int'
    }

    attribute_map = {
        'resource_id_key': 'resource_id_key',
        'resource_id_value': 'resource_id_value',
        'resource_name': 'resource_name',
        'resource_type': 'resource_type',
        'time': 'time',
        'event_type': 'event_type',
        'event_message': 'event_message',
        'elapsed_seconds': 'elapsed_seconds'
    }

    def __init__(self, resource_id_key=None, resource_id_value=None, resource_name=None, resource_type=None, time=None, event_type=None, event_message=None, elapsed_seconds=None):
        """StackEventResponse

        The model defined in huaweicloud sdk

        :param resource_id_key: 资源的id名称，即对应资源作为唯一id使用的值的名称，当资源未创建的时候，不返回resource_id_key
        :type resource_id_key: str
        :param resource_id_value: 资源的id值，即对应资源作为唯一id使用的值，当资源未创建的时候，不返回resource_id_value
        :type resource_id_value: str
        :param resource_name: 资源的名称
        :type resource_name: str
        :param resource_type: 资源的类型
        :type resource_type: str
        :param time: 事件发生的时间，格式遵循RFC3339，即yyyy-mm-ddTHH:MM:SSZ，如1970-01-01T00:00:00Z
        :type time: str
        :param event_type: 此次事件的类型 * &#x60;LOG&#x60; - 记录状态信息，比如当前状态，目标状态等。详细信息将在EventMessage中存储。此为暂时状态， 因为目前我们无法解析terraform的log，只能直全部以LOG形式打出，未来我们吃掉terraform内核以后， 将去除这个状态，并改为下列的更精准的状态 * &#x60;ERROR&#x60; - 记录失败信息 * &#x60;DRIFT&#x60; - 记录资源偏移信息 * &#x60;SUMMARY&#x60; - 记录资源变更结果总结 * &#x60;CREATION_IN_PROGRESS&#x60; - 正在生成 * &#x60;CREATION_FAILED&#x60; - 生成失败 * &#x60;CREATION_COMPLETE&#x60; - 生成完成 * &#x60;DELETION_IN_PROGRESS&#x60; - 正在删除 * &#x60;DELETION_FAILED&#x60; - 删除失败 * &#x60;DELETION_COMPLETE&#x60; - 已经删除 * &#x60;DELETION_SKIPPED&#x60; - 跳过删除。未来我们将支持，用户可以从IaC中删除，但是不真的删除资源本身 * &#x60;UPDATE_IN_PROGRESS&#x60; - 正在更新。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION * &#x60;UPDATE_FAILED&#x60; - 更新失败。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后 * &#x60;UPDATE_COMPLETE&#x60; - 更新完成。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION
        :type event_type: str
        :param event_message: 事件对应的详细信息
        :type event_message: str
        :param elapsed_seconds: 资源改动所花的时间，以秒为单位
        :type elapsed_seconds: int
        """
        
        

        self._resource_id_key = None
        self._resource_id_value = None
        self._resource_name = None
        self._resource_type = None
        self._time = None
        self._event_type = None
        self._event_message = None
        self._elapsed_seconds = None
        self.discriminator = None

        if resource_id_key is not None:
            self.resource_id_key = resource_id_key
        if resource_id_value is not None:
            self.resource_id_value = resource_id_value
        if resource_name is not None:
            self.resource_name = resource_name
        if resource_type is not None:
            self.resource_type = resource_type
        if time is not None:
            self.time = time
        if event_type is not None:
            self.event_type = event_type
        if event_message is not None:
            self.event_message = event_message
        if elapsed_seconds is not None:
            self.elapsed_seconds = elapsed_seconds

    @property
    def resource_id_key(self):
        """Gets the resource_id_key of this StackEventResponse.

        资源的id名称，即对应资源作为唯一id使用的值的名称，当资源未创建的时候，不返回resource_id_key

        :return: The resource_id_key of this StackEventResponse.
        :rtype: str
        """
        return self._resource_id_key

    @resource_id_key.setter
    def resource_id_key(self, resource_id_key):
        """Sets the resource_id_key of this StackEventResponse.

        资源的id名称，即对应资源作为唯一id使用的值的名称，当资源未创建的时候，不返回resource_id_key

        :param resource_id_key: The resource_id_key of this StackEventResponse.
        :type resource_id_key: str
        """
        self._resource_id_key = resource_id_key

    @property
    def resource_id_value(self):
        """Gets the resource_id_value of this StackEventResponse.

        资源的id值，即对应资源作为唯一id使用的值，当资源未创建的时候，不返回resource_id_value

        :return: The resource_id_value of this StackEventResponse.
        :rtype: str
        """
        return self._resource_id_value

    @resource_id_value.setter
    def resource_id_value(self, resource_id_value):
        """Sets the resource_id_value of this StackEventResponse.

        资源的id值，即对应资源作为唯一id使用的值，当资源未创建的时候，不返回resource_id_value

        :param resource_id_value: The resource_id_value of this StackEventResponse.
        :type resource_id_value: str
        """
        self._resource_id_value = resource_id_value

    @property
    def resource_name(self):
        """Gets the resource_name of this StackEventResponse.

        资源的名称

        :return: The resource_name of this StackEventResponse.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this StackEventResponse.

        资源的名称

        :param resource_name: The resource_name of this StackEventResponse.
        :type resource_name: str
        """
        self._resource_name = resource_name

    @property
    def resource_type(self):
        """Gets the resource_type of this StackEventResponse.

        资源的类型

        :return: The resource_type of this StackEventResponse.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this StackEventResponse.

        资源的类型

        :param resource_type: The resource_type of this StackEventResponse.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def time(self):
        """Gets the time of this StackEventResponse.

        事件发生的时间，格式遵循RFC3339，即yyyy-mm-ddTHH:MM:SSZ，如1970-01-01T00:00:00Z

        :return: The time of this StackEventResponse.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this StackEventResponse.

        事件发生的时间，格式遵循RFC3339，即yyyy-mm-ddTHH:MM:SSZ，如1970-01-01T00:00:00Z

        :param time: The time of this StackEventResponse.
        :type time: str
        """
        self._time = time

    @property
    def event_type(self):
        """Gets the event_type of this StackEventResponse.

        此次事件的类型 * `LOG` - 记录状态信息，比如当前状态，目标状态等。详细信息将在EventMessage中存储。此为暂时状态， 因为目前我们无法解析terraform的log，只能直全部以LOG形式打出，未来我们吃掉terraform内核以后， 将去除这个状态，并改为下列的更精准的状态 * `ERROR` - 记录失败信息 * `DRIFT` - 记录资源偏移信息 * `SUMMARY` - 记录资源变更结果总结 * `CREATION_IN_PROGRESS` - 正在生成 * `CREATION_FAILED` - 生成失败 * `CREATION_COMPLETE` - 生成完成 * `DELETION_IN_PROGRESS` - 正在删除 * `DELETION_FAILED` - 删除失败 * `DELETION_COMPLETE` - 已经删除 * `DELETION_SKIPPED` - 跳过删除。未来我们将支持，用户可以从IaC中删除，但是不真的删除资源本身 * `UPDATE_IN_PROGRESS` - 正在更新。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION * `UPDATE_FAILED` - 更新失败。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后 * `UPDATE_COMPLETE` - 更新完成。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION

        :return: The event_type of this StackEventResponse.
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this StackEventResponse.

        此次事件的类型 * `LOG` - 记录状态信息，比如当前状态，目标状态等。详细信息将在EventMessage中存储。此为暂时状态， 因为目前我们无法解析terraform的log，只能直全部以LOG形式打出，未来我们吃掉terraform内核以后， 将去除这个状态，并改为下列的更精准的状态 * `ERROR` - 记录失败信息 * `DRIFT` - 记录资源偏移信息 * `SUMMARY` - 记录资源变更结果总结 * `CREATION_IN_PROGRESS` - 正在生成 * `CREATION_FAILED` - 生成失败 * `CREATION_COMPLETE` - 生成完成 * `DELETION_IN_PROGRESS` - 正在删除 * `DELETION_FAILED` - 删除失败 * `DELETION_COMPLETE` - 已经删除 * `DELETION_SKIPPED` - 跳过删除。未来我们将支持，用户可以从IaC中删除，但是不真的删除资源本身 * `UPDATE_IN_PROGRESS` - 正在更新。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION * `UPDATE_FAILED` - 更新失败。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后 * `UPDATE_COMPLETE` - 更新完成。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION

        :param event_type: The event_type of this StackEventResponse.
        :type event_type: str
        """
        self._event_type = event_type

    @property
    def event_message(self):
        """Gets the event_message of this StackEventResponse.

        事件对应的详细信息

        :return: The event_message of this StackEventResponse.
        :rtype: str
        """
        return self._event_message

    @event_message.setter
    def event_message(self, event_message):
        """Sets the event_message of this StackEventResponse.

        事件对应的详细信息

        :param event_message: The event_message of this StackEventResponse.
        :type event_message: str
        """
        self._event_message = event_message

    @property
    def elapsed_seconds(self):
        """Gets the elapsed_seconds of this StackEventResponse.

        资源改动所花的时间，以秒为单位

        :return: The elapsed_seconds of this StackEventResponse.
        :rtype: int
        """
        return self._elapsed_seconds

    @elapsed_seconds.setter
    def elapsed_seconds(self, elapsed_seconds):
        """Sets the elapsed_seconds of this StackEventResponse.

        资源改动所花的时间，以秒为单位

        :param elapsed_seconds: The elapsed_seconds of this StackEventResponse.
        :type elapsed_seconds: int
        """
        self._elapsed_seconds = elapsed_seconds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StackEventResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaos-3.1.15-py2.py3-none-any.whl: huaweicloudsdkaos/v1/model/stack_event_response.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class StackEventResponse:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id_key': 'str',
        'resource_id_value': 'str',
        'resource_name': 'str',
        'resource_type': 'str',
        'time': 'str',
        'event_type': 'str',
        'event_message': 'str',
        'elapsed_seconds': 'int'
    }

    attribute_map = {
        'resource_id_key': 'resource_id_key',
        'resource_id_value': 'resource_id_value',
        'resource_name': 'resource_name',
        'resource_type': 'resource_type',
        'time': 'time',
        'event_type': 'event_type',
        'event_message': 'event_message',
        'elapsed_seconds': 'elapsed_seconds'
    }

    def __init__(self, resource_id_key=None, resource_id_value=None, resource_name=None, resource_type=None, time=None, event_type=None, event_message=None, elapsed_seconds=None):
        """StackEventResponse

        The model defined in huaweicloud sdk

        :param resource_id_key: 资源的id名称，即对应资源作为唯一id使用的值的名称，当资源未创建的时候，不返回resource_id_key
        :type resource_id_key: str
        :param resource_id_value: 资源的id值，即对应资源作为唯一id使用的值，当资源未创建的时候，不返回resource_id_value
        :type resource_id_value: str
        :param resource_name: 资源的名称
        :type resource_name: str
        :param resource_type: 资源的类型
        :type resource_type: str
        :param time: 事件发生的时间，格式遵循RFC3339，即yyyy-mm-ddTHH:MM:SSZ，如1970-01-01T00:00:00Z
        :type time: str
        :param event_type: 此次事件的类型 * &#x60;LOG&#x60; - 记录状态信息，比如当前状态，目标状态等。详细信息将在EventMessage中存储。此为暂时状态， 因为目前我们无法解析terraform的log，只能直全部以LOG形式打出，未来我们吃掉terraform内核以后， 将去除这个状态，并改为下列的更精准的状态 * &#x60;ERROR&#x60; - 记录失败信息 * &#x60;DRIFT&#x60; - 记录资源偏移信息 * &#x60;SUMMARY&#x60; - 记录资源变更结果总结 * &#x60;CREATION_IN_PROGRESS&#x60; - 正在生成 * &#x60;CREATION_FAILED&#x60; - 生成失败 * &#x60;CREATION_COMPLETE&#x60; - 生成完成 * &#x60;DELETION_IN_PROGRESS&#x60; - 正在删除 * &#x60;DELETION_FAILED&#x60; - 删除失败 * &#x60;DELETION_COMPLETE&#x60; - 已经删除 * &#x60;DELETION_SKIPPED&#x60; - 跳过删除。未来我们将支持，用户可以从资源编排服务中删除，但是不真的删除资源本身 * &#x60;UPDATE_IN_PROGRESS&#x60; - 正在更新。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION * &#x60;UPDATE_FAILED&#x60; - 更新失败。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后 * &#x60;UPDATE_COMPLETE&#x60; - 更新完成。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION
        :type event_type: str
        :param event_message: 事件对应的详细信息
        :type event_message: str
        :param elapsed_seconds: 资源改动所花的时间，以秒为单位
        :type elapsed_seconds: int
        """
        
        

        self._resource_id_key = None
        self._resource_id_value = None
        self._resource_name = None
        self._resource_type = None
        self._time = None
        self._event_type = None
        self._event_message = None
        self._elapsed_seconds = None
        self.discriminator = None

        if resource_id_key is not None:
            self.resource_id_key = resource_id_key
        if resource_id_value is not None:
            self.resource_id_value = resource_id_value
        if resource_name is not None:
            self.resource_name = resource_name
        if resource_type is not None:
            self.resource_type = resource_type
        if time is not None:
            self.time = time
        if event_type is not None:
            self.event_type = event_type
        if event_message is not None:
            self.event_message = event_message
        if elapsed_seconds is not None:
            self.elapsed_seconds = elapsed_seconds

    @property
    def resource_id_key(self):
        """Gets the resource_id_key of this StackEventResponse.

        资源的id名称，即对应资源作为唯一id使用的值的名称，当资源未创建的时候，不返回resource_id_key

        :return: The resource_id_key of this StackEventResponse.
        :rtype: str
        """
        return self._resource_id_key

    @resource_id_key.setter
    def resource_id_key(self, resource_id_key):
        """Sets the resource_id_key of this StackEventResponse.

        资源的id名称，即对应资源作为唯一id使用的值的名称，当资源未创建的时候，不返回resource_id_key

        :param resource_id_key: The resource_id_key of this StackEventResponse.
        :type resource_id_key: str
        """
        self._resource_id_key = resource_id_key

    @property
    def resource_id_value(self):
        """Gets the resource_id_value of this StackEventResponse.

        资源的id值，即对应资源作为唯一id使用的值，当资源未创建的时候，不返回resource_id_value

        :return: The resource_id_value of this StackEventResponse.
        :rtype: str
        """
        return self._resource_id_value

    @resource_id_value.setter
    def resource_id_value(self, resource_id_value):
        """Sets the resource_id_value of this StackEventResponse.

        资源的id值，即对应资源作为唯一id使用的值，当资源未创建的时候，不返回resource_id_value

        :param resource_id_value: The resource_id_value of this StackEventResponse.
        :type resource_id_value: str
        """
        self._resource_id_value = resource_id_value

    @property
    def resource_name(self):
        """Gets the resource_name of this StackEventResponse.

        资源的名称

        :return: The resource_name of this StackEventResponse.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this StackEventResponse.

        资源的名称

        :param resource_name: The resource_name of this StackEventResponse.
        :type resource_name: str
        """
        self._resource_name = resource_name

    @property
    def resource_type(self):
        """Gets the resource_type of this StackEventResponse.

        资源的类型

        :return: The resource_type of this StackEventResponse.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this StackEventResponse.

        资源的类型

        :param resource_type: The resource_type of this StackEventResponse.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def time(self):
        """Gets the time of this StackEventResponse.

        事件发生的时间，格式遵循RFC3339，即yyyy-mm-ddTHH:MM:SSZ，如1970-01-01T00:00:00Z

        :return: The time of this StackEventResponse.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this StackEventResponse.

        事件发生的时间，格式遵循RFC3339，即yyyy-mm-ddTHH:MM:SSZ，如1970-01-01T00:00:00Z

        :param time: The time of this StackEventResponse.
        :type time: str
        """
        self._time = time

    @property
    def event_type(self):
        """Gets the event_type of this StackEventResponse.

        此次事件的类型 * `LOG` - 记录状态信息，比如当前状态，目标状态等。详细信息将在EventMessage中存储。此为暂时状态， 因为目前我们无法解析terraform的log，只能直全部以LOG形式打出，未来我们吃掉terraform内核以后， 将去除这个状态，并改为下列的更精准的状态 * `ERROR` - 记录失败信息 * `DRIFT` - 记录资源偏移信息 * `SUMMARY` - 记录资源变更结果总结 * `CREATION_IN_PROGRESS` - 正在生成 * `CREATION_FAILED` - 生成失败 * `CREATION_COMPLETE` - 生成完成 * `DELETION_IN_PROGRESS` - 正在删除 * `DELETION_FAILED` - 删除失败 * `DELETION_COMPLETE` - 已经删除 * `DELETION_SKIPPED` - 跳过删除。未来我们将支持，用户可以从资源编排服务中删除，但是不真的删除资源本身 * `UPDATE_IN_PROGRESS` - 正在更新。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION * `UPDATE_FAILED` - 更新失败。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后 * `UPDATE_COMPLETE` - 更新完成。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION

        :return: The event_type of this StackEventResponse.
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this StackEventResponse.

        此次事件的类型 * `LOG` - 记录状态信息，比如当前状态，目标状态等。详细信息将在EventMessage中存储。此为暂时状态， 因为目前我们无法解析terraform的log，只能直全部以LOG形式打出，未来我们吃掉terraform内核以后， 将去除这个状态，并改为下列的更精准的状态 * `ERROR` - 记录失败信息 * `DRIFT` - 记录资源偏移信息 * `SUMMARY` - 记录资源变更结果总结 * `CREATION_IN_PROGRESS` - 正在生成 * `CREATION_FAILED` - 生成失败 * `CREATION_COMPLETE` - 生成完成 * `DELETION_IN_PROGRESS` - 正在删除 * `DELETION_FAILED` - 删除失败 * `DELETION_COMPLETE` - 已经删除 * `DELETION_SKIPPED` - 跳过删除。未来我们将支持，用户可以从资源编排服务中删除，但是不真的删除资源本身 * `UPDATE_IN_PROGRESS` - 正在更新。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION * `UPDATE_FAILED` - 更新失败。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后 * `UPDATE_COMPLETE` - 更新完成。此处的更新特指非替换式更新，如果是替换式更新，则使用CREATION后DELETION

        :param event_type: The event_type of this StackEventResponse.
        :type event_type: str
        """
        self._event_type = event_type

    @property
    def event_message(self):
        """Gets the event_message of this StackEventResponse.

        事件对应的详细信息

        :return: The event_message of this StackEventResponse.
        :rtype: str
        """
        return self._event_message

    @event_message.setter
    def event_message(self, event_message):
        """Sets the event_message of this StackEventResponse.

        事件对应的详细信息

        :param event_message: The event_message of this StackEventResponse.
        :type event_message: str
        """
        self._event_message = event_message

    @property
    def elapsed_seconds(self):
        """Gets the elapsed_seconds of this StackEventResponse.

        资源改动所花的时间，以秒为单位

        :return: The elapsed_seconds of this StackEventResponse.
        :rtype: int
        """
        return self._elapsed_seconds

    @elapsed_seconds.setter
    def elapsed_seconds(self, elapsed_seconds):
        """Sets the elapsed_seconds of this StackEventResponse.

        资源改动所花的时间，以秒为单位

        :param elapsed_seconds: The elapsed_seconds of this StackEventResponse.
        :type elapsed_seconds: int
        """
        self._elapsed_seconds = elapsed_seconds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StackEventResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
